"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Emits log messages via an EventEmitter.
 * @internal
 */
function createLogEmitter(emitter, debug) {
    function log(message, data) {
        if (typeof message === "string") {
            log.info(message, data);
        }
        else {
            log.error(message, data);
        }
    }
    log.info = (message, data) => {
        let logEventData = { ...data, message, level: "info" /* Info */ };
        emitter.emit("log" /* Log */, logEventData);
    };
    log.debug = (message, data) => {
        if (debug) {
            let logEventData = { ...data, message, level: "debug" /* Debug */ };
            emitter.emit("log" /* Log */, logEventData);
        }
    };
    log.warn = (warning, data) => {
        let logEventData = { ...data, ...splitError(warning, debug), level: "warning" /* Warning */ };
        emitter.emit("log" /* Log */, logEventData);
    };
    log.error = (error, data) => {
        let logEventData = { ...data, ...splitError(error, debug), level: "error" /* Error */ };
        emitter.emit("log" /* Log */, logEventData);
    };
    return log;
}
exports.createLogEmitter = createLogEmitter;
/**
 * Splits an Error or error message into two separate values.
 */
function splitError(arg, debug) {
    if (typeof arg === "string") {
        return { message: arg };
    }
    else {
        let error = arg;
        let message = arg.message || String(arg);
        if (debug) {
            message = arg.stack || message;
        }
        return { message, error };
    }
}
exports.splitError = splitError;
//# sourceMappingURL=log-emitter.js.map